/*
 * GTI (Generic Tools Infrastructure)
 * Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2015
 * Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2015
 * Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
 *
 * See the file LICENSE.txt in the package base directory for details
 */

#include <mpi.h>
#include <stddef.h>

/**
 * This test evaluates whether we require const correctness that was introduced with MPI 3.
 * The basic const correctness test is "ft_mpi_const_correctness.c".
 *
 * This test looks at an unclear case that differs depending on MPI,
 * which is MPI_Type_hindexed:
 * - OpenMPI 1.8.2 (MPI-3) chooses to not use const in its definition
 * - Cray mpich 7.1.1 (MPI-?) chooses to use const in its definition
 *
 * So this specialized test case determines which handling we need for this specific function.
 * (The underlying thing is that MPI_Type_hindexed was deprecated, so
 *  apparently OpenMPI choose to not adapt it to const correctness,
 *  while the Cray MPICH apparently does so)
 */

int main(int argc, char **argv)
{
    /*Dummy call to avoid any optimization out, its not functional, just to please compilers*/
    const int blens[3] = {1,1,1};
    const MPI_Aint bdisps[3] = {1,1,1};
    MPI_Type_hindexed (1,blens,bdisps,MPI_INT,NULL);
    return 0;
}
