# CMake file
# Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2015
# Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2015
# Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
#
# See the file LICENSE.txt in the package base directory for details
#
# @file FindLIBUNWIND.cmake
#       Detects the GTI installation.
#
# @author Jan Felix Münchhalfen
# @date 03.01.2011

SET(GTI_FOUND_LIBUNWIND FALSE)

IF (NOT GTI_FOUND_LIBUNWIND)
    SET(GTI_LIBUNWIND_INCLUDE_PATH "GTI_LIBUNWIND_INCLUDE_PATH-NOTFOUND" CACHE PATH "Libunwind Include Path")
    SET(GTI_LIBUNWIND_LIB_PATH "GTI_LIBUNWIND_LIB_PATH-NOTFOUND" CACHE PATH "Libunwind Library Path")
    FIND_PATH (GTI_LIBUNWIND_INCLUDE_PATH NAMES libunwind.h PATHS ${GTI_LIBUNWIND_INCLUDE_PATH}/ ${PnMPI_HOME}/libunwind/include)
    IF (EXISTS ${GTI_LIBUNWIND_INCLUDE_PATH})
        #If we have it, no issues here
        #MESSAGE(STATUS "LIBUNWIND: libunwind.h found in ${GTI_LIBUNWIND_INCLUDE_PATH}")
        #FIND_LIBRARY (GTI_LIBUNWIND_LIB_PATH NAMES unwind PATHS ${PnMPI_HOME}/libunwind/src/.libs PATH_SUFFIXES lib/ lib64/)
        FIND_PATH (GTI_LIBUNWIND_LIB_PATH NAMES libunwind.so PATHS ${GTI_LIBUNWIND_LIB_PATH}/ ${PnMPI_HOME}/libunwind/src/.libs PATH_SUFFIXES lib/ lib64/)
        
        IF (EXISTS ${GTI_LIBUNWIND_LIB_PATH})
            MESSAGE(STATUS "Enabled optional libunwind integration, using: ${GTI_LIBUNWIND_LIB_PATH}")
            #Lets try to not be too bold here
            #COLORMESSAGE("LIBUNWIND support is enabled!" FALSE)
            SET (GTI_FOUND_LIBUNWIND TRUE)
			  add_definitions(-DGTI_FOUND_LIBUNWIND)
        ENDIF (EXISTS ${GTI_LIBUNWIND_LIB_PATH})
    ENDIF (EXISTS ${GTI_LIBUNWIND_INCLUDE_PATH})
    
    IF (NOT GTI_LIBUNWIND_LIB_PATH)
        MESSAGE(STATUS 
          "Optional libunwind integration not activated since no libunwind " 
          "library was found, if wanted, specify GTI_LIBUNWIND_INCLUDE_PATH "
          "and GTI_LIBUNWIND_LIB_PATH to provide hints")
        #Lets try to not be too bold here
        #COLORMESSAGE("LIBUNWIND support is NOT enabled!" TRUE)
    ENDIF (NOT GTI_LIBUNWIND_LIB_PATH)
ENDIF (NOT GTI_FOUND_LIBUNWIND)

