# CMake file
# Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2015
# Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2015
# Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
#
# See the file LICENSE.txt in the package base directory for details
#
# @file FindOMPT.cmake
#       Detects the GTI installation.
#
# @author Jan Felix Münchhalfen
# @date 03.01.2011

SET(GTI_FOUND_OMPT FALSE)

IF (NOT GTI_FOUND_OMPT)
    SET(GTI_OMPT_INCLUDE_PATH "GTI_OMPT_INCLUDE_PATH-NOTFOUND" CACHE PATH "OMPT Includes Path")
    SET(GTI_OMPT_LIB_PATH "GTI_OMPT_LIBS-NOTFOUND" CACHE PATH "OMPT Library Path")
    FIND_PATH (GTI_OMPT_INCLUDE_PATH NAMES ompt.h PATHS ${GTI_OMPT_INCLUDE_PATH}/ ${PnMPI_HOME}/runtime/include NO_DEFAULT_PATH)
    
    IF (EXISTS ${GTI_OMPT_INCLUDE_PATH})
        #MESSAGE(STATUS "OMPT: ompt.h found in ${GTI_OMPT_INCLUDE_PATH}")
        #FIND_LIBRARY (GTI_OMPT_LIB_PATH NAMES iomp5 PATHS ${PnMPI_HOME}/libomp_oss NO_DEFAULT_PATH)
        FIND_PATH (GTI_OMPT_LIB_PATH NAMES libiomp5.so PATHS ${GTI_OMPT_LIB_PATH}/ ${PnMPI_HOME}/runtime/lib NO_DEFAULT_PATH)
    
        IF (EXISTS ${GTI_OMPT_LIB_PATH})
            MESSAGE(STATUS "Enabled optional ompt integration, using: ${GTI_OMPT_LIB_PATH}")
            #Lets try to not be too bold here
            #COLORMESSAGE("OMPT support is enabled!" FALSE)
            SET (GTI_FOUND_OMPT TRUE)
			  add_definitions(-DGTI_FOUND_OMPT)
        ENDIF (EXISTS ${GTI_OMPT_LIB_PATH})
    ENDIF (EXISTS ${GTI_OMPT_INCLUDE_PATH})
    
    IF (NOT GTI_OMPT_LIB_PATH)
        ##Todo: change "Experimental" to "Optional" at some future point
        MESSAGE(STATUS 
          "Experimental OpenMP tools interface integration not activated since no " 
          "compatible runtime library was found, if wanted, specify "
          "GTI_OMPT_INCLUDE_PATH and GTI_OMPT_LIB_PATH to provide hints")
        #Lets try to not be too bold here
        #COLORMESSAGE("LIBUNWIND support is NOT enabled!" TRUE)
    ENDIF (NOT GTI_OMPT_LIB_PATH)
ENDIF (NOT GTI_FOUND_OMPT)

